@@ -453,6 +453,10 @@ void DolphinDetailsView::currentChanged(const QModelIndex& current, const QModel
     if (m_keyPressed) {
         setCurrentIndex(current);
     }
+
+    // If folders are expanded, the width which is available for editing may have changed
+    // because it depends on the level of the current item in the folder hierarchy.
+    adjustMaximumSizeForEditing(current);
 }
 
 bool DolphinDetailsView::eventFilter(QObject* watched, QEvent* event)
@@ -645,8 +649,19 @@ void DolphinDetailsView::updateColumnVisibility()
             setColumnHidden(i, hide);
         }
         
-        const int from = headerView->visualIndex(i);
-        headerView->moveSection(from, columnPositions[i]);
+        // If the list columnPositions has been written by an older Dolphin version,
+        // its length might be smaller than DolphinModel::ExtraColumnCount. Therefore,
+        // we have to check if item number i exists before accessing it.
+        if (i < columnPositions.length()) {
+            const int position = columnPositions[i];
+
+            // The position might be outside the correct range if the list columnPositions
+            // has been written by a newer Dolphin version with more columns.
+            if (position < DolphinModel::ExtraColumnCount) {
+                const int from = headerView->visualIndex(i);
+                headerView->moveSection(from, position);
+            }
+        }
     }
     
     resizeColumns();
@@ -680,6 +695,8 @@ void DolphinDetailsView::slotHeaderSectionResized(int logicalIndex, int oldSize,
     if ((QApplication::mouseButtons() & Qt::LeftButton) && header()->underMouse()) {
         disableAutoResizing();
     }
+
+    adjustMaximumSizeForEditing(currentIndex());
 }
 
 void DolphinDetailsView::slotActivationChanged(bool active)
@@ -913,6 +930,10 @@ void DolphinDetailsView::setFoldersExpandable(bool expandable)
     settings->setExpandableFolders(expandable);
     setRootIsDecorated(expandable);
     setItemsExpandable(expandable);
+
+    // The width of the space which is available for editing has changed
+    // because of the (dis)appearance of the expanding toggles
+    adjustMaximumSizeForEditing(currentIndex());
 }
 
 void DolphinDetailsView::slotExpanded(const QModelIndex& index)
@@ -1061,6 +1082,12 @@ bool DolphinDetailsView::isAboveExpandingToggle(const QPoint& pos) const
     return false;
 }
 
+void DolphinDetailsView::adjustMaximumSizeForEditing(const QModelIndex& index)
+{
+    // Make sure that the full width of the "Name" column is available for "Rename Inline"
+    m_extensionsFactory->fileItemDelegate()->setMaximumSize(QTreeView::visualRect(index).size());
+}
+
 DolphinDetailsView::ElasticBand::ElasticBand() :
     show(false),
     origin(),
