@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Peter Penz (peter.penz@gmx.at)                  *
+ *   Copyright (C) 2006-2009 by Peter Penz <peter.penz@gmx.at>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -32,9 +32,9 @@
 #include <libdolphin_export.h>
 
 class DolphinController;
-class SelectionManager;
 class DolphinCategoryDrawer;
-class DolphinViewAutoScroller;
+class DolphinSortFilterProxyModel;
+class ViewExtensionsFactory;
 
 /**
  * @brief Represents the view, where each item is shown as an icon.
@@ -47,7 +47,9 @@ class LIBDOLPHINPRIVATE_EXPORT DolphinIconsView : public KCategorizedView
     Q_OBJECT
 
 public:
-    explicit DolphinIconsView(QWidget* parent, DolphinController* controller);
+    explicit DolphinIconsView(QWidget* parent,
+                              DolphinController* controller,
+                              DolphinSortFilterProxyModel* proxyModel);
     virtual ~DolphinIconsView();
 
 protected slots:
@@ -62,6 +64,7 @@ protected:
     virtual void dragLeaveEvent(QDragLeaveEvent* event);
     virtual void dragMoveEvent(QDragMoveEvent* event);
     virtual void dropEvent(QDropEvent* event);
+    virtual QModelIndex moveCursor(CursorAction cursorAction, Qt::KeyboardModifiers modifiers);
     virtual void keyPressEvent(QKeyEvent* event);
     virtual void wheelEvent(QWheelEvent* event);
     virtual void showEvent(QShowEvent* event);
@@ -91,9 +94,8 @@ private:
 
 private:
     DolphinController* m_controller;
-    SelectionManager* m_selectionManager;
-    DolphinViewAutoScroller* m_autoScroller;
     DolphinCategoryDrawer* m_categoryDrawer;
+    ViewExtensionsFactory* m_extensionsFactory;
 
     QFont m_font;
     QSize m_decorationSize;
