@@ -109,8 +109,6 @@ DolphinView::DolphinView(QWidget* parent,
 
     connect(m_controller, SIGNAL(urlChanged(const KUrl&)),
             this, SIGNAL(urlChanged(const KUrl&)));
-    connect(m_controller, SIGNAL(requestUrlChange(const KUrl&)),
-            this, SLOT(slotRequestUrlChange(const KUrl&)));
 
     connect(m_controller, SIGNAL(requestContextMenu(const QPoint&, const QList<QAction*>&)),
             this, SLOT(openContextMenu(const QPoint&, const QList<QAction*>&)));
@@ -1181,12 +1179,6 @@ void DolphinView::slotDeleteFileFinished(KJob* job)
     }
 }
 
-void DolphinView::slotRequestUrlChange(const KUrl& url)
-{
-    emit requestUrlChange(url);
-    m_controller->setUrl(url);
-}
-
 void DolphinView::slotDirListerCompleted()
 {
     if (!m_expanderActive) {
@@ -1195,7 +1187,8 @@ void DolphinView::slotDirListerCompleted()
 
     if (!m_newFileNames.isEmpty()) {
         // select all newly added items created by a paste operation or
-        // a drag & drop operation
+        // a drag & drop operation, and clear the previous selection
+        m_viewAccessor.itemView()->clearSelection();
         const int rowCount = m_viewAccessor.proxyModel()->rowCount();
         QItemSelection selection;
         for (int row = 0; row < rowCount; ++row) {
