@@ -27,6 +27,7 @@
 #include "exporters.h"
 #include "settings.h"
 #include "commands.h"
+#include "commandhistory.h"
 #include "kebsearchline.h"
 #include "bookmarklistview.h"
 
@@ -36,11 +37,11 @@
 #include <QtGui/QSplitter>
 #include <QtGui/QLayout>
 #include <QtGui/QLabel>
+#include <QtGui/QApplication>
 
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <ktoggleaction.h>
-#include <kapplication.h>
 #include <kbookmark.h>
 #include <kbookmarkmanager.h>
 #include <kdebug.h>
@@ -51,67 +52,6 @@
 #include <kmessagebox.h>
 #include <kstandardaction.h>
 
-#include <assert.h>
-#include <QtCore/QBool>
-
-
-
-CmdHistory* CmdHistory::s_self = 0;
-
-CmdHistory::CmdHistory(KActionCollection *collection)
-    : m_commandHistory(collection) {
-    connect(&m_commandHistory, SIGNAL( commandExecuted(K3Command *) ),
-            SLOT( slotCommandExecuted(K3Command *) ));
-    assert(!s_self);
-    s_self = this; // this is hacky
-}
-
-CmdHistory* CmdHistory::self() {
-    assert(s_self);
-    return s_self;
-}
-
-void CmdHistory::slotCommandExecuted(K3Command *k) {
-    KEBApp::self()->notifyCommandExecuted();
-
-    IKEBCommand * cmd = dynamic_cast<IKEBCommand *>(k);
-    Q_ASSERT(cmd);
-
-    KBookmark bk = CurrentMgr::bookmarkAt(cmd->affectedBookmarks());
-    Q_ASSERT(bk.isGroup());
-    CurrentMgr::self()->notifyManagers(bk.toGroup());
-}
-
-void CmdHistory::notifyDocSaved() {
-    m_commandHistory.documentSaved();
-}
-
-void CmdHistory::didCommand(K3Command *cmd) {
-    if (!cmd)
-        return;
-    m_commandHistory.addCommand(cmd, false);
-    CmdHistory::slotCommandExecuted(cmd);
-}
-
-void CmdHistory::addCommand(K3Command *cmd) {
-    if (!cmd)
-        return;
-    m_commandHistory.addCommand(cmd);
-}
-
-void CmdHistory::addInFlightCommand(K3Command *cmd)
-{
-    if(!cmd)
-        return;
-    m_commandHistory.addCommand(cmd, false);
-}
-
-void CmdHistory::clearHistory() {
-    m_commandHistory.clear();
-}
-
-/* -------------------------- */
-
 CurrentMgr *CurrentMgr::s_mgr = 0;
 
 CurrentMgr::CurrentMgr()
@@ -152,10 +92,10 @@ void CurrentMgr::createManager(const QString &filename, const QString &dbusObjec
 
     kDebug()<<"DBus Object name: "<<dbusObjectName;
     m_mgr = KBookmarkManager::managerForFile(filename, dbusObjectName);
-   
+
     if ( m_model ) {
         m_model->setRoot(root());
-    } else { 
+    } else {
         m_model = new KBookmarkModel(root());
     }
 
@@ -170,11 +110,11 @@ void CurrentMgr::slotBookmarksChanged(const QString &, const QString &) {
         return;
     }
 
-    m_model->setRoot(m_mgr->root());    
+    m_model->setRoot(m_mgr->root());
 
     CmdHistory::self()->clearHistory();
     KEBApp::self()->updateActions();
-    KEBApp::self()->expandAll();
+    //KEBApp::self()->expandAll();
 }
 
 void CurrentMgr::notifyManagers(const KBookmarkGroup& grp)
@@ -248,11 +188,12 @@ KEBApp::KEBApp(
     mBookmarkListView->setModel( CurrentMgr::self()->model() );
     mBookmarkListView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mBookmarkListView->loadColumnSetting();
+    mBookmarkListView->loadFoldedState();
 
     KViewSearchLineWidget *searchline = new KViewSearchLineWidget(mBookmarkListView);
 
     mBookmarkFolderView = new BookmarkFolderView(mBookmarkListView);
-
+    mBookmarkFolderView->expandAll();
 
     QWidget * rightSide = new QWidget;
     QVBoxLayout *listLayout = new QVBoxLayout(rightSide);
@@ -272,8 +213,6 @@ KEBApp::KEBApp(
 
     setCentralWidget(hsplitter);
 
-    mBookmarkListView->expandAll();
-
     slotClipboardDataChanged();
     setAutoSaveSettings();
 
@@ -310,7 +249,6 @@ void KEBApp::reset(const QString & caption, const QString & bookmarksFileName)
     m_bookmarksFilename = bookmarksFileName;
     CurrentMgr::self()->createManager(m_bookmarksFilename, m_dbusObjectName); //FIXME this is still a memory leak (iff called by slotLoad)
     CurrentMgr::self()->model()->resetModel();
-    mBookmarkListView->expandAll();
     updateActions();
 }
 
@@ -356,7 +294,7 @@ SelcAbilities KEBApp::getSelectionAbilities() const
 
     if ( sel.count() > 0)
     {
-        selctionAbilities.deleteEnabled = true;       
+        selctionAbilities.deleteEnabled = true;
         selctionAbilities.itemSelected   = true;
         selctionAbilities.group          = nbk.isGroup();
         selctionAbilities.separator      = nbk.isSeparator();
