@@ -25,8 +25,6 @@
 #include <ktabwidget.h>
 #include <kmimetype.h>
 
-#include "kdatecombo.h"
-
 class QButtonGroup;
 class QPushButton;
 class QRadioButton;
@@ -37,10 +35,11 @@ class QDate;
 class QRegExp;
 class KDialog;
 class KComboBox;
-class QSpinBox;
+class KIntSpinBox;
 class QLabel;
 
 class KfDirDialog;
+class KDateCombo;
 
 class KfindTabWidget: public KTabWidget
 {
@@ -66,6 +65,9 @@ public:
 
 public Q_SLOTS:
   void setFocus();
+  void slotUpdateDateLabelsForNumber(int value);
+  void slotUpdateDateLabelsForType(int index);
+  void slotUpdateByteComboBox(int value);
 
 private Q_SLOTS:
   void getDirectory();
@@ -100,6 +102,8 @@ private:
   QString date2String(const QDate &);
   QDate &string2Date(const QString &, QDate * );
 
+  void updateDateLabels(int type, int value);
+
   QWidget *pages[3];
 
   //1st page
@@ -115,12 +119,12 @@ private:
   QRadioButton *rb[2];
   KDateCombo * fromDate;
   KDateCombo * toDate;
-  QSpinBox *timeBox;
+  KIntSpinBox *timeBox;
 
   //3rd page
   KComboBox *sizeBox;
   KComboBox *sizeUnitBox;
-  QSpinBox *sizeEdit;
+  KIntSpinBox *sizeEdit;
   QCheckBox *caseContextCb;
   QCheckBox *binaryContextCb;
   QCheckBox *regexpContentCb;
