@@ -42,6 +42,7 @@
 #include <klineedit.h>
 #include <kmessagebox.h>
 #include <kstandardaction.h>
+#include <kparts/part.h>
 
 KBookmarkManager* s_bookmarkManager = 0;
 
@@ -127,10 +128,8 @@ bool KonqSidebarBookmarkModule::handleTopLevelContextMenu( KonqSidebarTreeTopLev
 {
     QMenu *menu = new QMenu;
 
-    if (tree()->tabSupport()) {
-	menu->addAction( m_collection->action("folder_open_tabs") );
-	menu->addSeparator();
-    }
+    menu->addAction( m_collection->action("folder_open_tabs") );
+    menu->addSeparator();
     menu->addAction( m_collection->action("create_folder") );
 
     menu->addSeparator();
@@ -148,22 +147,18 @@ void KonqSidebarBookmarkModule::showPopupMenu()
     if (!bi)
         return;
 
-    bool tabSupported = tree()->tabSupport();
     QMenu *menu = new QMenu;
 
     if (bi->bookmark().isGroup()) {
-        if (tabSupported) {
-            menu->addAction( m_collection->action("folder_open_tabs") );
-            menu->addSeparator();
-        }
+        menu->addAction( m_collection->action("folder_open_tabs") );
+        menu->addSeparator();
         menu->addAction( m_collection->action("create_folder") );
         menu->addAction( m_collection->action("item_properties") );
         menu->addSeparator();
         menu->addAction( m_collection->action("delete_folder") );
     } else {
         menu->addAction( m_collection->action("open_window") );
-        if (tabSupported)
-            menu->addAction( m_collection->action("open_tab") );
+        menu->addAction( m_collection->action("open_tab") );
         menu->addAction( m_collection->action("copy_location") );
         menu->addSeparator();
         menu->addAction( m_collection->action("create_folder") );
@@ -402,7 +397,11 @@ void KonqSidebarBookmarkModule::slotOpenNewWindow()
     if (!bi)
         return;
 
-    emit tree()->createNewWindow( bi->bookmark().url() );
+    KParts::OpenUrlArguments args;
+    args.setActionRequestedByUser(true);
+    KParts::BrowserArguments browserArgs;
+    browserArgs.setForcesNewWindow(true);
+    emit tree()->createNewWindow(bi->bookmark().url(), args, browserArgs);
 }
 
 void KonqSidebarBookmarkModule::slotOpenTab()
@@ -418,24 +417,26 @@ void KonqSidebarBookmarkModule::slotOpenTab()
     else
 	return;
 
-#ifdef __GNUC__
-#warning newTab hack, must be done otherwise
-#endif
-#if 0
-    DCOPRef ref(kapp->dcopClient()->appId(), tree()->topLevelWidget()->name());
-
+    KParts::OpenUrlArguments args;
+    args.setActionRequestedByUser(true);
+    KParts::BrowserArguments browserArguments;
+    browserArguments.setNewTab(true);
     if (bookmark.isGroup()) {
         KBookmarkGroup group = bookmark.toGroup();
         bookmark = group.first();
         while (!bookmark.isNull()) {
-            if (!bookmark.isGroup() && !bookmark.isSeparator())
-                ref.call( "newTab(QString)", bookmark.url().url() );
+            if (!bookmark.isGroup() && !bookmark.isSeparator()) {
+                emit tree()->createNewWindow(bookmark.url(),
+                                             args,
+                                             browserArguments);
+            }
             bookmark = group.next(bookmark);
         }
     } else {
-        ref.call( "newTab(QString)", bookmark.url().url() );
+        emit tree()->createNewWindow(bookmark.url(),
+                                     args,
+                                     browserArguments);
     }
-#endif
 }
 
 void KonqSidebarBookmarkModule::slotCopyLocation()
@@ -526,7 +527,7 @@ void KonqSidebarBookmarkModule::fillGroup( KonqSidebarTreeItem * parentItem, con
                     item->setOpen(false);
             }
             else if ( bk.isSeparator() )
-                item->setVisible( false );
+                item->setVisible( false ); // ### this probably causes bug #78257
             else
                 item->setExpandable( false );
     }
@@ -568,7 +569,6 @@ BookmarkEditDialog::BookmarkEditDialog(const QString& title, const QString& url,
 
     bool folder = url.isNull();
     QGridLayout *grid = new QGridLayout( main );
-    grid->setSpacing( spacingHint() );
 
     QLabel *nameLabel = new QLabel(i18n("Name:"), main);
     nameLabel->setObjectName("title label");
