@@ -130,12 +130,6 @@ public:
    */
   KParts::ReadOnlyPart *attach( const KonqViewFactory &viewFactory );
 
-  /**
-   * Filters the CTRL+Tab event from the views and emits ctrlTabPressed to
-   make KonqMainWindow switch to the next view
-   */
-  virtual bool eventFilter(QObject*obj, QEvent *ev);
-
   /**
    * Inserts the widget and the statusbar into the layout
    */
