@@ -20,6 +20,7 @@
 
 #include "konqframevisitor.h"
 #include "konqframe.h"
+#include "konqview.h"
 
 bool KonqViewCollector::visit(KonqFrame* frame)
 {
@@ -33,3 +34,17 @@ QList<KonqView *> KonqViewCollector::collect(KonqFrameBase* topLevel)
     topLevel->accept(&collector);
     return collector.m_views;
 }
+
+bool KonqLinkableViewsCollector::visit(KonqFrame* frame)
+{
+    if (!frame->childView()->isFollowActive())
+        m_views.append(frame->childView());
+    return true;
+}
+
+QList<KonqView *> KonqLinkableViewsCollector::collect(KonqFrameBase* topLevel)
+{
+    KonqLinkableViewsCollector collector;
+    topLevel->accept(&collector);
+    return collector.m_views;
+}
