@@ -619,6 +619,7 @@ void Session::updateTerminalSize()
         {
             minLines = (minLines == -1) ? view->lines() : qMin( minLines , view->lines() );
             minColumns = (minColumns == -1) ? view->columns() : qMin( minColumns , view->columns() );
+            view->processFilters();
         }
     }
 
@@ -1205,6 +1206,7 @@ void Session::saveSession(KConfigGroup& group)
     group.writePathEntry("WorkingDir", currentWorkingDirectory());
     group.writeEntry("LocalTab",       tabTitleFormat(LocalTabTitle));
     group.writeEntry("RemoteTab",      tabTitleFormat(RemoteTabTitle));
+    group.writeEntry("Encoding",       QString(codec()));
 }
 
 void Session::restoreSession(KConfigGroup& group)
@@ -1217,6 +1219,8 @@ void Session::restoreSession(KConfigGroup& group)
     if (!value.isEmpty()) setTabTitleFormat(LocalTabTitle, value);
     value = group.readEntry("RemoteTab");
     if (!value.isEmpty()) setTabTitleFormat(RemoteTabTitle, value);
+    value = group.readEntry("Encoding");
+    if (!value.isEmpty()) setCodec(value.toUtf8());
 }
 
 SessionGroup::SessionGroup(QObject* parent)
