@@ -435,7 +435,6 @@ void SessionController::setupActions()
 
     // Copy Input To -> All Tabs in Current Window
     _copyToAllTabsAction = collection->addAction("copy-input-to-all-tabs");
-    _copyToAllTabsAction->setShortcut( QKeySequence(Qt::CTRL+Qt::SHIFT+Qt::Key_Comma) );
     _copyToAllTabsAction->setText(i18n("&All Tabs in Current Window") );
     _copyToAllTabsAction->setCheckable(true);
     connect( _copyToAllTabsAction , SIGNAL(triggered()) , this , SLOT(copyInputToAllTabs()) );
@@ -773,6 +772,9 @@ void SessionController::copyInputToSelectedTabs()
 
 void SessionController::copyInputToNone()
 {
+    if (!_copyToGroup)      // No 'Copy To' is active
+        return;
+
     QSet<Session*> group =
        QSet<Session*>::fromList(SessionManager::instance()->sessions());
     for(QSet<Session*>::iterator iterator = group.begin();
@@ -1393,11 +1395,11 @@ void SaveHistoryTask::jobResult(KJob* job)
         KMessageBox::sorry( 0 , i18n("A problem occurred when saving the output.\n%1",job->errorString()) );
     }
 
-    SaveJob& info = _jobSession[job];
+    TerminalCharacterDecoder * decoder = _jobSession[job].decoder;
 
     _jobSession.remove(job);
 
-    delete info.decoder;
+    delete decoder;
 
     // notify the world that the task is done
     emit completed(true);
