@@ -426,7 +426,8 @@ void ViewManager::splitView(Qt::Orientation orientation)
     {
         Session* session = _sessionMap[(TerminalDisplay*)existingViewIter.next()];
         TerminalDisplay* display = createTerminalDisplay(session);
-        applyProfile(display,SessionManager::instance()->sessionProfile(session),false);
+        const Profile::Ptr info = SessionManager::instance()->sessionProfile(session);
+        applyProfile(display, info, false);
         ViewProperties* properties = createController(session,display);
 
         _sessionMap[display] = session;
@@ -434,8 +435,15 @@ void ViewManager::splitView(Qt::Orientation orientation)
         // create a container using settings from the first 
         // session in the previous container
         if ( !container )
-            container = createContainer(SessionManager::instance()->sessionProfile(session));
+            container = createContainer(info);
 
+        int tabBarMode = info->property<int>(Profile::TabBarMode);
+        if ( tabBarMode == Profile::AlwaysHideTabBar )
+            container->setNavigationDisplayMode(ViewContainer::AlwaysHideNavigation);
+        else if ( tabBarMode == Profile::AlwaysShowTabBar )
+            container->setNavigationDisplayMode(ViewContainer::AlwaysShowNavigation);
+        else if ( tabBarMode == Profile::ShowTabBarAsNeeded )
+            container->setNavigationDisplayMode(ViewContainer::ShowNavigationAsNeeded);
         container->addView(display,properties);
         session->addView( display );
     }
@@ -646,6 +654,7 @@ void ViewManager::containerMoveViewRequest(int index, int id, bool& moved)
         return;
 
     createView(controller->session(),container,index);
+    controller->session()->refresh();
     moved = true;
 }
 void ViewManager::setNavigationMethod(NavigationMethod method)
@@ -955,6 +964,15 @@ void ViewManager::restoreSessions(const KConfigGroup& group)
         _viewSplitter->activeContainer()->setActiveView(display);
         display->setFocus(Qt::OtherFocusReason);
     }
+
+    if (ids.isEmpty()) // Session file is unusable, start default Profile
+    {
+        Profile::Ptr profile = SessionManager::instance()->defaultProfile();
+        Session* session = SessionManager::instance()->createSession(profile);
+        createView(session);
+        if (!session->isRunning())
+            session->run();
+    }
 }
 
 uint qHash(QPointer<TerminalDisplay> display)
