@@ -127,7 +127,8 @@ int konsole_wcwidth(quint16 ucs)
       (ucs >= 0xf900 && ucs <= 0xfaff) || /* CJK Compatibility Ideographs */
       (ucs >= 0xfe30 && ucs <= 0xfe6f) || /* CJK Compatibility Forms */
       (ucs >= 0xff00 && ucs <= 0xff5f) || /* Fullwidth Forms */
-      (ucs >= 0xffe0 && ucs <= 0xffe6) /* do not compare UINT16 with 0x20000 ||
+      (ucs >= 0xffe0 && ucs <= 0xffe6) || /* do not compare UINT16 with 0x20000 */
+      (ucs >= 0x300a && ucs <= 0x300b)  /* Specal character 《 and 》(Unicode Standard Annex #11) ||
       (ucs >= 0x20000 && ucs <= 0x2ffff) */));
 }
 
