@@ -103,10 +103,10 @@ protected:
     void createConfigurationInterface(KConfigDialog *parent);
     QList<QAction*> contextualActions();
     void constraintsEvent(Plasma::Constraints);
-    void mousePressEvent(QGraphicsSceneMouseEvent *event);
     void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
     void dragMoveEvent(QGraphicsSceneDragDropEvent *event);
     void dropEvent(QGraphicsSceneDragDropEvent *event);
+    QSizeF sizeHint(Qt::SizeHint which, const QSizeF &constraint) const;
 
 protected slots:
     // These slots are for KonqPopupMenu
@@ -119,22 +119,16 @@ protected slots:
     void deleteSelectedIcons();
     void renameSelectedIcon();
 
+    void emptyTrashBin();
     void undoTextChanged(const QString &text);
     void toggleIconsLocked(bool locked);
     void toggleAlignToGrid(bool align);
     void toggleDirectoriesFirst(bool enable);
     void sortingChanged(QAction *action);
     void aboutToShowCreateNew();
-    void aboutToShowWindowList();
     void updateIconWidget();
     void iconWidgetClicked();
 
-    void addPanel();
-    void addPanel(const QString &plugin);
-    void runCommand();
-    void lockScreen();
-    void logout();
-
     void activated(const QModelIndex &index);
     void indexesMoved(const QModelIndexList &indexes);
     void contextMenuRequest(QWidget *widget, const QPoint &screenPos);
@@ -152,10 +146,10 @@ protected slots:
  
 private:
     void addActions(AbstractItemView *view);
+    QColor textColor() const;
     void setupIconView();
     void setUrl(const KUrl &url);
     QSize iconSize() const;
-    QSize gridSize() const;
     void createActions();
     void updateSortActionsState();
     void updateListViewState();
@@ -186,9 +180,6 @@ private:
     QString m_filterFiles;
     QStringList m_filterFilesMimeList;
     QPointer<KNewMenu> m_newMenu;
-#ifdef HAVE_KWORKSPACE
-    KWindowListMenu *m_windowListMenu;
-#endif
     KActionCollection m_actionCollection;
     QActionGroup *m_sortingGroup;
     int m_sortColumn;
