@@ -59,6 +59,7 @@
 #include "animator.h"
 
 #include <Plasma/Containment>
+#include <Plasma/ContainmentActions>
 #include <Plasma/Corona>
 #include <Plasma/PaintUtils>
 #include <Plasma/Theme>
@@ -1848,6 +1849,17 @@ void IconView::mousePressEvent(QGraphicsSceneMouseEvent *event)
 
         const Plasma::Containment *parent = qobject_cast<Plasma::Containment*>(parentWidget());
 
+        // If a containment action is assigned to the left mouse button,
+        // give it precedence over rubberband-selections
+        Plasma::Containment *containment = qobject_cast<Plasma::Containment*>(parentWidget());
+        if (containment && containment->isContainment()) {
+            const QString trigger = Plasma::ContainmentActions::eventToString(event);
+            if (!containment->containmentActions(trigger).isEmpty()) {
+                event->ignore();
+                return;
+            }
+        }
+
         if (event->modifiers() & Qt::ControlModifier) {
             // Make the current selection persistent
             m_selectionModel->select(m_selectionModel->selection(), QItemSelectionModel::Select);
